.. note::

   Weblate provided callback URL during the authentication includes configured
   domain. In case you get errors about URL mismatch, you might want to fix
   this, see :ref:`production-site`.
